@@ -25,7 +25,7 @@
            maxvar=15,
            nvar=nlevels(y)+1,
            ntreeTest=100,
-	   weight=F) {    
+	   weight=FALSE) {    
 
     nsample=nrow(x)
     nvariable=ncol(x)
@@ -65,7 +65,7 @@
 
 
     ##compute the weights (if needed) for each sample
-    if(weight==T){
+    if(weight){
 	for(boot in 1:Bsample){
 		numWeight[,boot]=summary(y[matTrain[,boot]])
 		classWeight[,boot]=nsample/numWeight[,boot]
@@ -103,7 +103,7 @@
 	ytest=y[test]
 	ntest <- nrow(xtest)
         
-	if (weight==T){ vectWeight=classWeight[,boot]}	
+	if (weight){ vectWeight=classWeight[,boot]}	
         
                                         #choix fixe, voir plus tard majority vote wins here
 	cutoff <- rep(1 / nclass, nclass)
@@ -175,17 +175,17 @@
 
 #this e632+ code comes from the ipred package from Thorsten and from the varselRF package from Diaz
 
-	one=mean(err.test, na.rm=T)
+	one=mean(err.test, na.rm=TRUE)
 	#one <- mean(apply(cbind(mat.pred.test, as.numeric(y)), 1, function(x) {mean(x[-(Bsample + 1)] != x[Bsample + 1],na.rm = TRUE)}), na.rm = TRUE)
 	#cat("\n  one :",one,"\n") 
 
-	resubst=mean(err.inbag, na.rm=T)
-	#resubst <- mean(mat.pred.inbag != as.numeric(y), na.rm=T)
+	resubst=mean(err.inbag, na.rm=TRUE)
+	#resubst <- mean(mat.pred.inbag != as.numeric(y), na.rm=TRUE)
 	#cat("\n  resubst :",resubst,"\n") 
 
 	err632 <- 0.368 * resubst + 0.632 * one
 
-	gamma <-sum(outer(as.numeric(y),as.numeric(mat.pred.inbag),function(x, y) ifelse(x == y, 0, 1)),na.rm=T)/(length(y)^2)
+	gamma <-sum(outer(as.numeric(y),as.numeric(mat.pred.inbag),function(x, y) ifelse(x == y, 0, 1)),na.rm=TRUE)/(length(y)^2)
 
 	r <- (one - resubst)/(gamma - resubst)
 	r <- ifelse(one > resubst & gamma > resubst, r, 0)
